@@ -3,7 +3,7 @@ use Carp;
 use strict;
 use Class::ISA;
 
-$CGI::Application::VERSION = '4.02';
+$CGI::Application::VERSION = '4.03';
 
 my %INSTALLED_CALLBACKS = (
 #	hook name          package                 sub
@@ -32,6 +32,15 @@ sub new {
 	my $self = {};
 	bless($self, $class);
 
+    ### SET UP DEFAULT VALUES ###
+    #
+    # We set them up here and not in the setup() because a subclass
+    # which implements setup() still needs default values!
+
+    $self->header_type('header');
+    $self->mode_param('rm');
+    $self->start_mode('start');
+
 	# Process optional new() parameters
 	my $rprops;
 	if (ref($args[0]) eq 'HASH') {
@@ -68,15 +77,6 @@ sub new {
 	# down the line.
 	$self->call_hook('init', @args);
 
-	### SET UP DEFAULT VALUES ###
-	#
-	# We set them up here and not in the setup() because a subclass
-	# which implements setup() still needs default values!
-
-	$self->header_type('header');
-	$self->mode_param('rm');
-	$self->start_mode('start') unless defined $self->start_mode;
-
 	# Call setup() method, which should be implemented in the sub-class!
 	$self->setup();
 
